
#include <string>
#include "Charon_ConfigDefs.hpp"

namespace charon {

  std::string version() {
    return("Charon: 2.2");
  }

}
